# cromo
Contraint Reasoning Over MOdels

Installation
------------
`pip install cromo`

Example Usage
-------------
* Clone the repository
* Go to the cromo directory
* Example run of cromo on rough terrain
`cromo search start Fire src/cromo/test/georgetown.geojson "2020-10-20" "2020-10-30"
* Example run of cromo on flat terrain
`cromo search start Fire src/cromo/test/whiterock.geojson "2021-03-01" "2021-03-31"`
